@@ -6,21 +6,27 @@ from optparse import OptionParser
 import webbrowser as browser
 
 from github.utils import urlopen2, get_remote_info, edit_text, \
-    get_remote_info_from_option
+    get_remote_info_from_option, get_prog
 
 def pprint_issue(issue, verbose=True):
-    title = "#%s %s" % (issue['number'], issue['title'])
+    if verbose:
+        indent = ""
+    else:
+        indent = " " * (5 - len(str(issue['number'])))
+    title = "%s%s. %s" % (indent, issue['number'], issue['title'])
     print title
     if verbose:
         print "-" * len(title)
-        print "%s" % issue['body']
-        print "---"
-        print "state: %s" % issue['state']
-        print "%s votes" % issue['votes']
-        print "created: %s" % issue['created_at']
+        if issue['body']:
+            print "%s" % issue['body']
+        print
+        print "    state: %s" % issue['state']
+        print "     user: %s" % issue['user']
+        print "    votes: %s" % issue['votes']
+        print "  created: %s" % issue['created_at']
         updated = issue.get('updated_at')
         if updated and not updated == issue['created_at']:
-            print "updated: %s" % updated
+            print "  updated: %s" % updated
         print
     
 def handle_error(result):
@@ -95,7 +101,7 @@ class Commands(object):
         
     def search(self, search_term=None, state='open', verbose=False, **kwargs):
         if not search_term:
-            example = "gh-i search experimental"
+            example = "%s search experimental" % get_prog()
             msg = "error: search term required\nexample: %s" % example
             print msg
             sys.exit(1)
@@ -103,7 +109,7 @@ class Commands(object):
         search_term_quoted = search_term_quoted.replace(".", "%2E")
         result = self.__submit('search', search_term, state)
         issues = get_key(result, 'issues')
-        print "searching for '%s' returned %s issues" % (search_term, len(issues))
+        print "# searching for '%s' returned %s issues" % (search_term, len(issues))
         for issue in issues:
             pprint_issue(issue, verbose)
         
@@ -114,8 +120,12 @@ class Commands(object):
                 issues_url = issues_url_template % (self.user, self.repo, state)
             else:
                 issues_url = issues_url_template % (self.user, self.repo, "")
-            browser.open(issues_url)
-            sys.exit(0)
+            try:
+                browser.open(issues_url)
+            except:
+                print "error: opening page in web browser failed"
+            else:
+                sys.exit(0)
             
         if state == 'all':
             states = ['open', 'closed']
@@ -125,9 +135,8 @@ class Commands(object):
             result = self.__submit('list', st)
             issues = get_key(result, 'issues')
             if issues:
-                header = "%s issues (%s):" % (st, len(issues))
+                header = "# %s issues on %s/%s" % (st, self.user, self.repo)
                 print header
-                print "-" * len(header)
                 for issue in issues:
                     pprint_issue(issue, verbose)
             else:
@@ -136,12 +145,16 @@ class Commands(object):
                 print # new line between states
         
     def show(self, number=None, webbrowser=False, **kwargs):
-        validate_number(number, example="gh-i show 1")
+        validate_number(number, example="%s show 1" % get_prog())
         if webbrowser:
             issue_url_template = "http://github.com/%s/%s/issues/%s/find"
             issue_url = issue_url_template % (self.user, self.repo, number)
-            browser.open(issue_url)
-            sys.exit(0)
+            try:
+                browser.open(issue_url)
+            except:
+                print "error: opening page in web browser failed"
+            else:
+                sys.exit(0)
         issue = self.__get_issue(number)
         print
         pprint_issue(issue)
@@ -154,21 +167,21 @@ class Commands(object):
         pprint_issue(issue)
         
     def close(self, number=None, **kwargs):
-        validate_number(number, example="gh-i close 1")
+        validate_number(number, example="%s close 1" % get_prog())
         result = self.__submit('close', number)
         issue = get_key(result, 'issue')
         print
         pprint_issue(issue)
         
     def reopen(self, number=None, **kwargs):
-        validate_number(number, example="gh-i reopen 1")
+        validate_number(number, example="%s reopen 1" % get_prog())
         result = self.__submit('reopen', number)
         issue = get_key(result, 'issue')
         print
         pprint_issue(issue)
         
     def edit(self, number=None, **kwargs):
-        validate_number(number, example="gh-i edit 1")
+        validate_number(number, example="%s edit 1" % get_prog())
         gh_issue = self.__get_issue(number)
         output = {'title': gh_issue['title'], 'body': gh_issue['body']}
         post_data = create_edit_issue(gh_issue)
@@ -182,11 +195,11 @@ class Commands(object):
         pprint_issue(issue)
         
     def label(self, command, label, number=None, **kwargs):
-        validate_number(number, example="gh-i label %s %s 1" % (command,
-            label))
+        validate_number(number, example="%s label %s %s 1" % (get_prog(), 
+            command, label))
         if command not in ['add', 'remove']:
             msg = "label command should use either 'add' or 'remove'\n"\
-                "example: gh-i label add %s %s" % (label, number)
+                "example: %s label add %s %s" % (get_prog(), label, number)
             raise Exception(msg)
         label = urllib.quote(label)
         label = label.replace(".", "%2E") # this is not done by urllib.quote
@@ -200,7 +213,7 @@ class Commands(object):
             print "no labels found for issue #%s" % number
         
     def comment(self, number=None, **kwargs):
-        validate_number(number, example="gh-i comment 1")
+        validate_number(number, example="%s comment 1" % get_prog())
         gh_issue = self.__get_issue(number)
         comment = create_comment(gh_issue)
         post_data = {'comment': comment}
